@@ -10,7 +10,7 @@ class Kv(object):
         self.__table__ = table
         db = db_by_table(table)
         self.cursor = cursor = db.cursor()
-        mc_key = _key_by_table(db, table, cursor) 
+        mc_key = _key_by_table(db.dbcnf['db'], table, cursor) 
         self.__mc_id__ = "%s'+%%s"%mc_key
         self.NULL = NULL
 
@@ -74,16 +74,16 @@ class Kv(object):
     def set(self, id, value):
         r = self.get(id)
         if r != value:
-            mc_key = self.__mc_id__ % id
-            cursor = self.cursor
             table = self.__table__
+            cursor = self.cursor
             cursor.execute(
-                'insert into %s (id,value) values (%%s,%%s) on duplicate key update value=values(value)' % table,
-                (id, value)
+                'insert into %s (id,value) values (%%s,%%s) on duplicate key update value=%%s' % table,
+                (id, value, value)
             )
             cursor.connection.commit()
             if value is None:
                 value = False
+            mc_key = self.__mc_id__ % id
             mc.set(mc_key, value)
 
     def mc_flush(self, id):
